@@ -4,7 +4,7 @@ cmake ${CMAKE_ARGS} \
   -DCMAKE_INSTALL_PREFIX:PATH=${PREFIX} \
   -DCMAKE_INSTALL_LIBDIR=lib \
   -DCMAKE_BUILD_TYPE=Release \
-  -DHIGHFIVE_UNIT_TESTS=ON \
+  -DHIGHFIVE_UNIT_TESTS=OFF \
   -DHIGHFIVE_EXAMPLES=OFF \
   -DHIGHFIVE_USE_BOOST=OFF \
   -DHIGHFIVE_USE_INSTALL_DEPS=OFF \
